@@ -31,17 +31,15 @@ void ComicData::init(const QString &id, const KConfigGroup &config)
 {
     mId = id;
     mCfg = config;
-    mFirstStripNum = 0;
-    mMaxStripNum = 0;
-    mScaleComic = false;
-    mIsLeftToRight = true;
-    mIsTopToBottom = true;
-
     load();
 }
 
 void ComicData::load()
 {
+    if (!mCfg.isValid()) {
+        return;
+    }
+
     mScaleComic = mCfg.readEntry("scaleToContent_" + mId, false);
     mMaxStripNum = mCfg.readEntry("maxStripNum_" + mId, 0);
     mStored = mCfg.readEntry("storedPosition_" + mId, QString());
@@ -49,6 +47,10 @@ void ComicData::load()
 
 void ComicData::save()
 {
+    if (!mCfg.isValid()) {
+        return;
+    }
+
     mCfg.writeEntry("scaleToContent_" + mId,  mScaleComic);
     mCfg.writeEntry("maxStripNum_" + mId, mMaxStripNum);
     mCfg.writeEntry("storedPosition_" + id(), mStored);
@@ -60,6 +62,11 @@ void ComicData::save()
     }
 }
 
+bool ComicData::isValid() const
+{
+    return mCfg.isValid();
+}
+
 void ComicData::setScaleComic(bool scale)
 {
     mScaleComic = scale;
